==> rstudio-1.1.453.tar.gz: rstudio-1.1.453/src/cpp/desktop/DesktopPosixApplication.hpp <==
/*
 * DesktopPosixApplication.hpp
 *
 * Copyright (C) 2009-12 by RStudio, Inc.
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

#ifndef DESKTOP_POSIX_APPLICATION_HPP
#define DESKTOP_POSIX_APPLICATION_HPP

#include "3rdparty/qtsingleapplication/QtSingleApplication"

#include "DesktopApplicationLaunch.hpp"

namespace rstudio {
namespace desktop {

class PosixApplication : public QtSingleApplication
{
    Q_OBJECT
public:

   PosixApplication(QString appName, int& argc, char* argv[])
    : QtSingleApplication(appName, argc, argv),
      pAppLauncher_(NULL)
   {
   }

   QString startupOpenFileRequest() const
   {
      return startupOpenFileRequest_;
   }

   void setAppLauncher(ApplicationLaunch* pAppLauncher)
   {
       pAppLauncher_ = pAppLauncher;
   }

signals:
    void openFileRequest(QString filename);

protected:
    virtual bool event(QEvent* pEvent);

private:
    QString startupOpenFileRequest_;
    ApplicationLaunch* pAppLauncher_;
};


} // namespace desktop
} // namespace rstudio

#endif // DESKTOP_POSIX_APPLICATION_HPP

==> rstudio-2022.02.3-492.tar.gz: rstudio-2022.02.3-492/src/cpp/desktop/DesktopPosixApplication.hpp <==
/*
 * DesktopPosixApplication.hpp
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

#ifndef DESKTOP_POSIX_APPLICATION_HPP
#define DESKTOP_POSIX_APPLICATION_HPP

#include "3rdparty/qtsingleapplication/QtSingleApplication"

#include "DesktopApplicationLaunch.hpp"

namespace rstudio {
namespace desktop {

class PosixApplication : public QtSingleApplication
{
    Q_OBJECT
public:

   PosixApplication(const QString& appName, int& argc, char* argv[])
    : QtSingleApplication(appName, argc, argv),
      pAppLauncher_(nullptr)
   {
   }

   QString startupOpenFileRequest() const
   {
      return startupOpenFileRequest_;
   }

   void setAppLauncher(ApplicationLaunch* pAppLauncher)
   {
       pAppLauncher_ = pAppLauncher;
   }

Q_SIGNALS:
    void openFileRequest(QString filename);

protected:
    bool event(QEvent* pEvent) override;

private:
    QString startupOpenFileRequest_;
    ApplicationLaunch* pAppLauncher_;
};


} // namespace desktop
} // namespace rstudio

#endif // DESKTOP_POSIX_APPLICATION_HPP
